#
# spec file for package python-M2Crypto
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-M2Crypto
Version:        0.22.5
Release:        11.5
Url:            https://gitlab.com/m2crypto/m2crypto
Summary:        Crypto and SSL toolkit for Python
License:        MIT and ZPL-2.0 and BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/M/M2Crypto/M2Crypto-%{version}.tar.gz
# PATCH-FIX-UPSTREAM M2Crypto-0.22.5-SSLv2_link_error.patch -- remove useless reference to SSL version 2
Patch0:         M2Crypto-0.22.5-SSLv2_link_error.patch
# PATCH-FIX-UPSTREAM Leading_zeroes_from_X.509_certificate_fingerprints_are_not_stripped.patch
Patch1:         Leading_zeroes_from_X.509_certificate_fingerprints_are_not_stripped.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  openssl
BuildRequires:  openssl-devel
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  swig
%if 0%{?suse_version}
%py_requires
BuildRequires:  fdupes
%endif
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
Provides:       python-m2crypto = %{version}
Obsoletes:      python-m2crypto < %{version}

%description
M2Crypto is a crypto and SSL toolkit for Python featuring the
following:

RSA, DSA, DH, HMACs, message digests, symmetric ciphers (including
AES). SSL functionality to implement clients and servers. HTTPS
extensions to Python's httplib, urllib, and xmlrpclib. Unforgeable
HMAC'ing AuthCookies for web session management. FTP/TLS client and
server. S/MIME. ZServerSSL: A HTTPS server for Zope. ZSmime: An S/MIME
messenger for Zope.

%prep
%setup -n M2Crypto-%{version}
%if 0%{?suse_version} >= 1315
%patch0 -p1
%patch1 -p1
%endif

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc README
%{python_sitearch}/*

%changelog
* Wed Nov  2 2016 aplanas@suse.com
- Fix Partner-L3: Guest registration failed when a head of smt
  server's fingerprint was zero (bsc#1001377)
  * Backport and adapt from upstream
    https://gitlab.com/m2crypto/m2crypto/commit/13a03b69ebd0de172ee6a7769ac42cd19be3a094
  * Add Leading_zeroes_from_X.509_certificate_fingerprints_are_not_stripped.patch
* Mon Dec  7 2015 opensuse@dstoecker.de
- fix SSLv2 link error for 13.2 and Leap 42.1 (M2Crypto-0.22.5-SSLv2_link_error.patch) (bsc#969731)
* Sat Dec  5 2015 opensuse@dstoecker.de
- update to 0.22.5, fix URL
- drop python-M2Crypto-SWIG-3.0.5.patch (functionality included upstream)
* Tue Feb 24 2015 dimstar@opensuse.org
- Add python-M2Crypto-SWIG-3.0.5.patch: Fix generation of M2Crypto
  module when using SWIG 3.0.5.
- Manually install _m2crypto shadow file: setup.py misses it.
  (boo#917759, boo#917815).
* Thu Apr 17 2014 hrvoje.senjan@gmail.com
- Update to 0.22.3
  * No changelog provided
- Demos are no longer included
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Sep 13 2013 jmatejek@suse.com
- fixed %%fdupes creating dangling symlinks (bnc#835687)
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Jan 14 2013 saschpe@suse.de
- Add requirement on python-pyOpenSSL, thinner than M2Crypto
* Wed Oct 31 2012 saschpe@suse.de
- Narrow the scops of fdupes (see bnc#784670)
* Tue Jan 24 2012 bwiedemann@suse.com
- fix Obsoletes
* Tue Dec 13 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Sep 22 2011 saschpe@suse.de
- Use SPDX style license
- Require python-distribute instead of python-setuptools
- Don't package testsuite
* Tue May 31 2011 saschpe@suse.de
- Renamed to python-M2Crypto to match PyPI upstream name
  * Added Provides/Obsoletes for python-m2crypto
- Fixed wrong-EOL, executable bit for docs rpmlint warnings
* Mon Apr 18 2011 saschpe@suse.de
- Update to 0.21.1
  - Support OpenSSL 1.0. Thanks to Miloslav Trmac for figuring out
    how to fix test_smime.py
  - Rename m2.engine_init to engine_init_error so that ENGINE_init
    and ENGINE_finish can be exposed, thanks to Erlo
  - 0.20 started releasing Python locks even around some operations
    that interacted with the Python runtime, potentially causing
    crashes and other weirdness, fix by Miloslav Trmac
  - Make httpslib.ProxyHTTPSConnection work with Python 2.3
- Removed patches that are now upstream
- Removed authors from spec
* Tue Apr 20 2010 lnussel@suse.de
- add some upstream patches to fix openssl 1.0 build
* Tue Mar 30 2010 matejcik@suse.cz
- update to 0.20.2
  * PGP subpackage is deprecated
  * m2urllib now closes sockets properly
  * port is now integer in ProxyHTTPSConnection
  * many bugfixes
  * test coverage up to 80%%
- enabled test suite in %%check phase
  (requires python-setuptools and openssl binary to run)
* Fri Feb 27 2009 jblunck@suse.de
- Update to M2Crypto 0.19.1.
* Tue Jan 13 2009 matejcik@suse.cz
- package taken from devel:languages:python in OBS
